import 'package:dart_redux_overview/src/result.dart';

class MarkdownRenderer {
  String render(Analysis analysis) {
    final buffer = StringBuffer();

    buffer.writeln('# Actions');
    buffer.writeln();
    _renderClassList(
      buffer,
      analysis.classes.where((x) => x.name.endsWith('Action')),
    );

    buffer.writeln('# States');
    buffer.writeln();
    _renderClassList(
      buffer,
      analysis.classes.where((x) => x.name.endsWith('State')),
    );

    return buffer.toString();
  }

  void _renderClassList(StringBuffer buffer, List<ClassAnalysis> classes) {
    for (var classs in classes) {
      buffer.writeln('* ${classs.name}');
      for (var constructor in classs.constructors) {
        final name = constructor.name != null ? '.${constructor.name}' : '';
        buffer.write('  * `$name(');
        final args = [
          ...constructor.requiredParameters.map((p) => '${p.type} ${p.name}'),
          ...constructor.namedParameters.map((p) => '${p.type} ${p.name}'),
        ];
        buffer.write(args.join(', '));
        buffer.write(')`');
        if (constructor.comments != null) {
          buffer.write(' : ${constructor.comments}');
        }
        buffer.writeln();
      }
    }
  }
}
